@@ -17,9 +17,8 @@ for (file in files) {
     title <- sub('"$', "", title)
     cat("* [",
       title,
-      "]( https://eliaskrainski.github.io/INLAspacetime/vignettes/",
-      sub("\\.Rmd", ".html", 
-          sub("/web", "", file)),
+      "]( https://eliaskrainski.github.io/INLAspacetime/articles/web/",
+      sub("\\.Rmd", ".html", file),
       ")\n",
       sep = ""
     )
